componenttools.Descendants
==========================

.. abjad-lineage:: abjad.tools.componenttools.Descendants.Descendants.Descendants

.. autoclass:: abjad.tools.componenttools.Descendants.Descendants.Descendants
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.componenttools.Descendants.Descendants.Descendants.component
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Descendants.Descendants.Descendants.music
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Descendants.Descendants.Descendants.start_offset
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Descendants.Descendants.Descendants.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Descendants.Descendants.Descendants.storage_format
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Descendants.Descendants.Descendants.timespan
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.componenttools.Descendants.Descendants.Descendants.__add__
   :noindex:

.. automethod:: abjad.tools.componenttools.Descendants.Descendants.Descendants.__contains__
   :noindex:

.. automethod:: abjad.tools.componenttools.Descendants.Descendants.Descendants.__eq__
   :noindex:

.. automethod:: abjad.tools.componenttools.Descendants.Descendants.Descendants.__ge__
   :noindex:

.. automethod:: abjad.tools.componenttools.Descendants.Descendants.Descendants.__getitem__
   :noindex:

.. automethod:: abjad.tools.componenttools.Descendants.Descendants.Descendants.__gt__
   :noindex:

.. automethod:: abjad.tools.componenttools.Descendants.Descendants.Descendants.__le__
   :noindex:

.. automethod:: abjad.tools.componenttools.Descendants.Descendants.Descendants.__len__
   :noindex:

.. automethod:: abjad.tools.componenttools.Descendants.Descendants.Descendants.__lt__
   :noindex:

.. automethod:: abjad.tools.componenttools.Descendants.Descendants.Descendants.__ne__
   :noindex:

.. automethod:: abjad.tools.componenttools.Descendants.Descendants.Descendants.__radd__
   :noindex:

.. automethod:: abjad.tools.componenttools.Descendants.Descendants.Descendants.__repr__
   :noindex:
